@@ -11,10 +11,9 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-import logging
-
 from django.core import urlresolvers
 from django.utils.translation import ugettext_lazy as _  # noqa
+from django.utils.translation import ungettext_lazy
 
 from horizon import messages
 from horizon import tables
@@ -22,6 +21,9 @@ from horizon.utils import memoized
 
 from designatedashboard import api
 
+from openstack_dashboard import policy
+from oslo_log import log as logging
+
 LOG = logging.getLogger(__name__)
 
 EDITABLE_RECORD_TYPES = (
@@ -48,13 +50,14 @@ class CreateDomain(tables.LinkAction):
 
     @memoized.memoized_method
     def allowed(self, request, datum):
-        try:
-            if self.table:
-                quota = api.designate.quota_get(request)
-                return quota['domains'] > len(self.table.data)
-        except Exception:
-            msg = _("The quotas could not be retrieved.")
-            messages.warning(request, msg)
+        if policy.check((("dns", "get_quota"),), request):
+            try:
+                if self.table:
+                    quota = api.designate.quota_get(request)
+                    return quota['domains'] > len(self.table.data)
+            except Exception:
+                msg = _("The quotas could not be retrieved.")
+                messages.warning(request, msg)
         return True
 
 
@@ -82,13 +85,25 @@ class DeleteDomain(tables.BatchAction):
 
     '''Batch action for deleting domains.'''
     name = "delete"
-    action_present = _("Delete")
-    action_past = _("Deleted")
-    data_type_singular = _("Domain")
-    data_type_plural = _("Domains")
     classes = ('btn-danger', 'btn-delete')
     policy_rules = (("dns", "delete_domain"),)
 
+    @staticmethod
+    def action_present(count):
+        return ungettext_lazy(
+            u"Delete Domain",
+            u"Delete Domains",
+            count
+        )
+
+    @staticmethod
+    def action_past(count):
+        return ungettext_lazy(
+            u"Deleted Domain",
+            u"Deleted Domains",
+            count
+        )
+
     def action(self, request, domain_id):
         api.designate.domain_delete(request, domain_id)
 
@@ -130,9 +145,24 @@ class EditRecord(tables.LinkAction):
 class DeleteRecord(tables.DeleteAction):
 
     '''Link action for navigating to the UpdateRecord view.'''
-    data_type_singular = _("Record")
     policy_rules = (("dns", "delete_record"),)
 
+    @staticmethod
+    def action_present(count):
+        return ungettext_lazy(
+            u"Delete Record",
+            u"Delete Records",
+            count
+        )
+
+    @staticmethod
+    def action_past(count):
+        return ungettext_lazy(
+            u"Deleted Record",
+            u"Deleted Records",
+            count
+        )
+
     def delete(self, request, record_id):
         domain_id = self.table.kwargs['domain_id']
         return api.designate.record_delete(request, domain_id, record_id)
@@ -146,12 +176,25 @@ class BatchDeleteRecord(tables.BatchAction):
     '''Batch action for deleting domain records.'''
 
     name = "delete"
-    action_present = _("Delete")
-    action_past = _("Deleted")
-    data_type_singular = _("Record")
     classes = ('btn-danger', 'btn-delete')
     policy_rules = (("dns", "delete_record"),)
 
+    @staticmethod
+    def action_present(count):
+        return ungettext_lazy(
+            u"Delete Record",
+            u"Delete Records",
+            count
+        )
+
+    @staticmethod
+    def action_past(count):
+        return ungettext_lazy(
+            u"Deleted Record",
+            u"Deleted Records",
+            count
+        )
+
     def action(self, request, record_id):
         domain_id = self.table.kwargs['domain_id']
         api.designate.record_delete(request, domain_id, record_id)
